@@ -276,6 +276,11 @@ public:
                                  const UString &a_value);
     void set_solib_prefix_path (const UString &a_name);
 
+    bool load_program (const UString &a_prog);
+
+    bool load_program (const UString &a_prog,
+		       const vector<UString> &a_args);
+
     bool load_program (const UString &a_prog,
                        const vector<UString> &a_args,
                        const UString &a_working_dir,
@@ -316,9 +321,9 @@ public:
 
     void init_output_handlers ();
 
-    void append_breakpoint_to_cache (const IDebugger::Breakpoint &a_break);
+    void append_breakpoint_to_cache (IDebugger::Breakpoint &a_break);
 
-    void append_breakpoints_to_cache (const map<int, IDebugger::Breakpoint>&);
+    void append_breakpoints_to_cache (map<int, IDebugger::Breakpoint>&);
 
     void do_continue (const UString &a_cookie);
 
@@ -584,6 +589,10 @@ public:
                           const ConstVariableSlot &a_s,
                           const UString &a_cookie);
 
+    void delete_variable (const UString &a_internal_name,
+			  const DefaultSlot &a_slot,
+			  const UString &a_cookie);
+
     void unfold_variable (VariableSafePtr a_var,
                           const UString &a_cookie);
 
