@@ -173,7 +173,25 @@ public:
     }
 
     bool
-    get_local_variables_row_iterator (Gtk::TreeModel::iterator &a_it)
+    is_local_variables_subtree_empty () const
+    {
+        LOG_FUNCTION_SCOPE_NORMAL_DD;
+
+        Gtk::TreeModel::iterator it;
+        if (!get_local_variables_row_iterator (it))
+            return true;
+        return it->children ().empty ();
+    }
+
+    bool
+    inspector_is_empty () const
+    {
+        return (is_function_arguments_subtree_empty ()
+                && is_local_variables_subtree_empty ());
+    }
+
+    bool
+    get_local_variables_row_iterator (Gtk::TreeModel::iterator &a_it) const
     {
         if (!local_variables_row_ref) {
             LOG_DD ("there is no variables row iter yet");
@@ -329,7 +347,6 @@ public:
                 row_it = tree_store->erase (row_it);
             }
         }
-        delete_vars_backend_peers (local_vars);
         local_vars.clear ();
         local_vars_changed_at_prev_stop.clear ();
     }
@@ -347,7 +364,6 @@ public:
                 row_it = tree_store->erase (*row_it);
             }
         }
-        delete_vars_backend_peers (function_arguments);
         function_arguments.clear ();
         func_args_changed_at_prev_stop.clear ();
     }
@@ -363,7 +379,6 @@ public:
         if (get_local_variables_row_iterator (parent_row_it)) {
             vutil::append_a_variable (a_var,
                                       *tree_view,
-                                      tree_store,
                                       parent_row_it,
                                       false /* do not truncate types */);
             tree_view->expand_row (tree_store->get_path (parent_row_it), false);
@@ -383,7 +398,6 @@ public:
             LOG_DD ("appending argument: " << a_var->name ());
             vutil::append_a_variable (a_var,
                                       *tree_view,
-                                      tree_store,
                                       parent_row_it,
                                       false /* do not truncate type */);
             tree_view->expand_row (tree_store->get_path (parent_row_it), false);
@@ -399,6 +413,7 @@ public:
 
         THROW_IF_FAIL (tree_view);
 
+        LOG_DD ("updating variable: " << a_var->internal_name ());
         Gtk::TreeModel::iterator parent_row_it;
         if (get_local_variables_row_iterator (parent_row_it)) {
             vutil::update_a_variable (a_var, *tree_view,
@@ -489,12 +504,14 @@ public:
 
         THROW_IF_FAIL (tree_store);
 
+        LOG_DD ("a_has_frame: " << a_has_frame);
+
         if (!a_has_frame)
             return;
 
         saved_frame = a_frame;
 
-        if (is_new_frame) {
+        if (is_new_frame || inspector_is_empty ()) {
             LOG_DD ("init tree view");
             re_init_tree_view ();
             LOG_DD ("list local variables");
@@ -591,19 +608,6 @@ public:
         }
     }
 
-    void
-    delete_vars_backend_peers (IDebugger::VariableList &a_vars)
-    {
-        for (IDebugger::VariableList::const_iterator it = a_vars.begin ();
-             it != a_vars.end ();
-             ++it) {
-            if (!(*it) || (*it)->internal_name ().empty ()) {
-                continue;
-            }
-            debugger->delete_variable (*it);
-        }
-    }
-
     Glib::RefPtr<Gtk::UIManager>
     get_ui_manager ()
     {
@@ -723,14 +727,14 @@ public:
         THROW_IF_FAIL (debugger);
         is_new_frame = (saved_frame != a_frame);
         saved_frame = a_frame;
+        saved_reason = a_reason;
+        saved_has_frame = a_has_frame;
 
         if (should_process_now ()) {
             finish_handling_debugger_stopped_event (a_reason,
                                                     a_has_frame,
                                                     a_frame);
         } else {
-            saved_reason = a_reason;
-            saved_has_frame = a_has_frame;
             is_up2date = false;
         }
 
@@ -796,8 +800,12 @@ public:
             // separately by a call to update_a_local_variable.
             // At least that's the current behaviour with the "GDB/MI
             // Variable Objects" based backend we are using.
+            LOG_DD ("Going to update var: " << (*it)->internal_name ()
+                    << " that has number of children "
+                    << (int) (*it)->members ().size ());
+
             update_a_local_variable (*it,
-                                     false /* do not update members */);
+                                     false /* Do not update members */);
             local_vars_changed_at_prev_stop.push_back (*it);
         }
 
@@ -931,7 +939,6 @@ public:
         Gtk::TreeModel::iterator var_it = tree_store->get_iter (a_var_node);
         vutil::update_unfolded_variable (a_var,
                                          *tree_view,
-                                         tree_store,
                                          var_it,
                                          false /* do not truncate type */);
         tree_view->expand_row (a_var_node, false);
